Computes confidence intervals for one or more parameters in a fitted model of class fcrr.
# S3 method for fcrr
confint(object, parm, level = 0.95, digits = max(options()$digits - 5, 2), ...)A matrix (or vector) with columns giving lower and upper confidence limits for each coefficient estimate.
fcrr object (output from fastCrr())
a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
the confidence level required
Number of significant difits to round to.
Additional arguments. Not implemented.
Prints out table of confidence intervals for the Fine-Gray model.