Prints summary statistics of a fcrr x
# S3 method for summary.fcrr
print(x, digits = max(options()$digits - 4, 3), ...)Prints the convergence status, log-pseudo likelihood, the estimated coefficients, the estimated standard errors, and the two-sided p-values for the test of the individual coefficients equal to 0.
output from fastCrr().
digits for rounding.
additional arguments to print().
Prints the convergence status, log-pseudo likelihood, the estimated coefficients, the estimated standard errors, and the two-sided p-values for the test of the individual coefficients equal to 0.